.. PyRopey documentation master file, created by
   sphinx-quickstart on Tue Feb  8 11:29:06 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyRopey's documentation!
===================================


.. toctree::

   README <README.md>


Classes and functions
---------------------
.. autosummary::
   :toctree: stubs

   ropey.Rope
   ropey.RopeBuilder


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
